@@ -19,6 +19,7 @@ pub mod cluster_slots_service;
 pub mod commitment_service;
 pub mod completed_data_sets_service;
 pub mod consensus;
+pub mod cost_update_service;
 pub mod fetch_stage;
 pub mod fork_choice;
 pub mod gen_keys;
@@ -46,6 +47,7 @@ pub mod sigverify;
 pub mod sigverify_shreds;
 pub mod sigverify_stage;
 pub mod snapshot_packager_service;
+pub mod system_monitor_service;
 pub mod test_validator;
 pub mod tpu;
 pub mod tree_diff;
