@@ -5,21 +5,17 @@
 //! transaction. All processing is done on the CPU by default and on a GPU
 //! if perf-libs are available
 
-use {
-    crate::sigverify,
-    crossbeam_channel::{SendError, Sender as CrossbeamSender},
-    solana_measure::measure::Measure,
-    solana_perf::packet::Packets,
-    solana_sdk::timing,
-    solana_streamer::streamer::{self, PacketReceiver, StreamerError},
-    std::{
-        collections::HashMap,
-        sync::mpsc::{Receiver, RecvTimeoutError},
-        thread::{self, Builder, JoinHandle},
-        time::Instant,
-    },
-    thiserror::Error,
-};
+use crate::sigverify;
+use crossbeam_channel::{SendError, Sender as CrossbeamSender};
+use solana_measure::measure::Measure;
+use solana_perf::packet::Packets;
+use solana_sdk::timing;
+use solana_streamer::streamer::{self, PacketReceiver, StreamerError};
+use std::collections::HashMap;
+use std::sync::mpsc::{Receiver, RecvTimeoutError};
+use std::thread::{self, Builder, JoinHandle};
+use std::time::Instant;
+use thiserror::Error;
 
 const MAX_SIGVERIFY_BATCH: usize = 10_000;
 
@@ -269,7 +265,8 @@ impl SigVerifyStage {
 
 #[cfg(test)]
 mod tests {
-    use {super::*, solana_perf::packet::Packet};
+    use super::*;
+    use solana_perf::packet::Packet;
 
     fn count_non_discard(packets: &[Packets]) -> usize {
         packets
